# Copyright (c) 2002 Juri Pakaste
# You may use and distribute this software under the terms of the
# GNU General Public License, version 2 or later

APPNAME = "Straw"
VERSION = "0.25"
STRAW_URL = "http://www.nongnu.org/straw/"
STRAW_REF_URL = "%sstraw-ref.html" % STRAW_URL

from Event import BaseSignal, SignalEmitter, ConfigOptionSignal, \
LocalConfigOptionSignal, FeedsChangedSignal, ItemsAddedSignal, \
ItemReadSignal,RefreshFeedDisplaySignal, NewItemsSignal, AllItemsReadSignal, \
ItemDeletedSignal, ImageUpdatedSignal, BlogURLChangedSignal, ItemOrderChangedSignal, \
OfflineModeChangedSignal, FindInterruptSignal, FeedPolledSignal, ItemStickySignal,FeedStatusChangedSignal, MainWindowSizeChangedSignal, \
MainPanePositionChangedSignal, SubPanePositionChangedSignal, \
NumberOfItemsStoredChangedSignal, SaveFeedsSignal, StatusDisplaySignal, \
FeedCategoriesChangedSignal, FeedDeletedSignal, FeedCreatedSignal, \
FeedErrorStatusChangedSignal, PollFrequencyChangedSignal, \
SubscriptionContentsUpdatedSignal, \
FeedCategoryChangedSignal, FeedCategoryListChangedSignal, \
FeedCategoryAddedSignal, FeedCategoryRemovedSignal, PollingStoppedSignal, \
FeedCategoryListLoadedSignal
import Config
from Feed import Feed
import FeedCategoryList
from FeedDataRouter import FeedDataRouter
import FeedList
from Main import Main
from MainWindow import MainWindow, CategorySelector
from PreferencesDialog import PreferencesDialog
from QueueDict import FeedQD
import SummaryParser
from SummaryItem import SummaryItem
from ParsedSummary import ParsedSummary
import ImageCache
from ImageCache import Image
from FindDialog import FindDialog
import file_selector
from FeedPropertiesDialog import FeedPropertiesDialog
import feedparser
import hig_alert
import OPML
import OPMLImport
import OPMLExport
import NetworkConstants
import URLFetch
import PollManager
import LookupManager
import DashboardFrontend
from FeedItems import FeedItems
import utils
import MessageManager
from Tray import Tray
import ValueMonitor
from MainloopManager import MainloopManager
